Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(658)

Unified Diff: components/nacl/common/nacl_cmd_line.h

Issue 196413016: Move CommandLine to base namespace. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 6 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/nacl/common/nacl_cmd_line.h
diff --git a/components/nacl/common/nacl_cmd_line.h b/components/nacl/common/nacl_cmd_line.h
index 4e4e75361354bce91197a98c6a3633261ea57209..60f7f22abe6108ca2c4c8ad81b00189ecf43c32a 100644
--- a/components/nacl/common/nacl_cmd_line.h
+++ b/components/nacl/common/nacl_cmd_line.h
@@ -5,12 +5,16 @@
#ifndef COMPONENTS_NACL_COMMON_NACL_CMD_LINE_H_
#define COMPONENTS_NACL_COMMON_NACL_CMD_LINE_H_
+namespace base {
class CommandLine;
+}
namespace nacl {
- // Copy all the relevant arguments from the command line of the current
- // process to cmd_line that will be used for launching the NaCl loader/broker.
- void CopyNaClCommandLineArguments(CommandLine* cmd_line);
-}
+
+// Copy all the relevant arguments from the command line of the current
+// process to cmd_line that will be used for launching the NaCl loader/broker.
+void CopyNaClCommandLineArguments(base::CommandLine* cmd_line);
+
+} // namespace nacl
#endif // COMPONENTS_NACL_COMMON_NACL_CMD_LINE_H_
« no previous file with comments | « components/nacl/browser/nacl_process_host.h ('k') | content/browser/android/child_process_launcher_android.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698